@@ -40,14 +40,14 @@ def sync_metadata_fields(lb_client, spark_table, metadata_index={}):
     lb_mdo, lb_metadata_names = refresh_metadata_ontology(lb_client)
     # Convert your meatdata_index values from strings into labelbox.schema.data_row_metadata.DataRowMetadataKind types
     conversion = {"enum" : DataRowMetadataKind.enum, "string" : DataRowMetadataKind.string, "datetime" : DataRowMetadataKind.datetime, "number" : DataRowMetadataKind.number}
+    print(metadata_index)
     # Sync your spark_table columns to your metadata_index
     if metadata_index and spark_table:
         column_names = [str(col[0]) for col in spark_table.dtypes]
         for metadata_field_name in metadata_index.keys():
             if metadata_field_name not in column_names:
                 spark_table = spark_table.withColumn(metadata_field_name, lit(None).cast(StringType()))
-    # Track data rows loaded from Databricks
-    metadata_index['lb_integration_source'] = "string"
+    spark_table.show()
     # Sync your Labelbox metadata ontology to your metadata_index
     for metadata_field_name in metadata_index.keys():
         metadata_type = metadata_index[metadata_field_name]
@@ -60,6 +60,9 @@ def sync_metadata_fields(lb_client, spark_table, metadata_index={}):
             enum_options = get_unique_values(spark_table, metadata_field_name) if metadata_type == "enum" else []
             lb_mdo.create_schema(name=metadata_field_name, kind=conversion[metadata_type], options=enum_options)
             lb_mdo, lb_metadata_names = refresh_metadata_ontology(lb_client)
+    # Track data rows loaded from Databricks
+    if 'lb_integration_source' not in lb_metadata_names:
+        lb_mdo.create_schema(name='lb_integration_source', kind=conversion["string"])
     return_value = spark_table if spark_table else True            
     return return_value
 
@@ -211,13 +214,12 @@ def batch_create_data_rows(client, dataset, global_key_to_upload_dict, skip_dupl
     for i in range(0,len(upload_list),batch_size):
         batch = upload_list[i:] if i + batch_size >= len(upload_list) else upload_list[i:i+batch_size]
         task = dataset.create_data_rows(batch)
+        task.wait_till_done()
         errors = task.errors
         if errors:
             print(f'Data Row Creation Error: {errors}')
             return errors
-        else:
-            upload_results.extend(task.result)
-    return upload_results   
+    return upload_results
 
 
 def upsert_function(upsert_dict_bytes, global_key_col, metadata_value_col):
